/**
 * Copyright (c) 2016-2019 人人开源 All rights reserved.
 *
 * https://www.renren.io
 *
 * 版权所有，侵权必究！
 */

package io.renren.modules.app.controller;

import io.renren.common.utils.R;
import io.renren.common.validator.ValidatorUtils;
import io.renren.modules.app.entity.UserEntity;
import io.renren.modules.app.form.RegisterForm;
import io.renren.modules.app.service.SmsCodeService;
import io.renren.modules.app.service.UserService;
import io.renren.common.utils.JsonUtils;
import io.renren.modules.app.entity.SmsStatusEntity;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;


/**
 * 注册
 *
 * @author Mark sunlightcs@gmail.com
 */
@RestController
@RequestMapping("/app")
@Api("APP注册接口")
public class AppRegisterController {
    @Autowired
    private UserService userService;

    @Autowired
    private SmsCodeService smsCodeService;

    /**
     * 短信验证码
     */
    @PostMapping("/mobilecode")
    public R mobileCode(String uuid, String phone) {
        // 获取短信验证码
        String code = smsCodeService.getCode(uuid, phone);
        try {
            String result = smsCodeService.sendCode(code, phone);
            return R.ok().put("result", result);
        } catch (Exception e) {
            e.printStackTrace();
            return R.error();
        }
    }

    @PostMapping("register")
    @ApiOperation("注册")
    public R register(@RequestBody RegisterForm form){
        boolean captcha = smsCodeService.validate(form.getUuid(), form.getCode());
		if(!captcha){
			return R.error("验证码不正确");
        }
        
        //表单校验
         ValidatorUtils.validateEntity(form);

         UserEntity user = new UserEntity();
         user.setPhone(form.getPhone());
         user.setUsername(form.getPhone());
         user.setPassword(form.getPassword());
         userService.saveUser(user);

        return R.ok();
    }
}
